Index: samplecode/SampleChart.cpp |
diff --git a/samplecode/SampleChart.cpp b/samplecode/SampleChart.cpp |
index 8d158f150655cb57c293285746bd0e0b57550315..0c8949c8effd39af446ab6de92fd391fb8d98ed2 100644 |
--- a/samplecode/SampleChart.cpp |
+++ b/samplecode/SampleChart.cpp |
@@ -24,7 +24,7 @@ static void gen_data(SkScalar yAvg, SkScalar ySpread, int count, SkTDArray<SkSca |
// Generates a path to stroke along the top of each plot and a fill path for the area below each |
// plot. The fill path is bounded below by the bottomData plot points or a horizontal line at |
// yBase if bottomData == NULL. |
// The plots are animated by rotating the data points by leftShift. |
static void gen_paths(const SkTDArray<SkScalar>& topData, |
const SkTDArray<SkScalar>* bottomData, |
@@ -35,7 +35,7 @@ static void gen_paths(const SkTDArray<SkScalar>& topData, |
plot->rewind(); |
fill->rewind(); |
plot->incReserve(topData.count()); |
- if (NULL == bottomData) { |
+ if (nullptr == bottomData) { |
fill->incReserve(topData.count() + 2); |
} else { |
fill->incReserve(2 * topData.count()); |
@@ -142,7 +142,7 @@ protected: |
fillPaint.setAntiAlias(true); |
fillPaint.setStyle(SkPaint::kFill_Style); |
- SkTDArray<SkScalar>* prevData = NULL; |
+ SkTDArray<SkScalar>* prevData = nullptr; |
for (int i = 0; i < kNumGraphs; ++i) { |
gen_paths(fData[i], |
prevData, |
@@ -164,7 +164,7 @@ protected: |
} |
fShift += kShiftPerFrame; |
- this->inval(NULL); |
+ this->inval(nullptr); |
} |
private: |
@@ -24,7 +24,7 @@ static void gen_data(SkScalar yAvg, SkScalar ySpread, int count, SkTDArray<SkSca |
// Generates a path to stroke along the top of each plot and a fill path for the area below each |
// plot. The fill path is bounded below by the bottomData plot points or a horizontal line at |
-// yBase if bottomData == NULL. |
+// yBase if bottomData == nullptr. |
// The plots are animated by rotating the data points by leftShift. |
static void gen_paths(const SkTDArray<SkScalar>& topData, |